Windows on Arm support
----------------------

Preliminary support for windows on arm64 target added.

Matplotlib for windows/arm64 requires FreeType 2.11 or above.

No binary wheels are available yet but can be built from source.
